@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import inspect
 import logging
 import os
 import tempfile
@@ -87,23 +88,41 @@ def public_class(
     if not isinstance(cls, Atomic):
         raise TypeError(f"Can only call on Atomic-metaclassed types!, {cls}")
     if property_path:
-        key, *_ = property_path
+        key, *rest = property_path
         if key not in cls._slots:
             raise ValueError(f"{key!r} is not a field on {cls.__name__}!")
         next_cls = cls._slots[key]
         if key in cls._nested_atomic_collection_keys:
-            if len(cls._nested_atomic_collection_keys[key]) > 1:
-                return tuple(
-                    public_class(typecls) for typecls in cls._nested_atomic_collection_keys[key]
-                )
-            next_cls, = cls._nested_atomic_collection_keys[key]
-        return public_class(next_cls, *property_path[1:])
+            atomic_classes = cls._nested_atomic_collection_keys[key]
+            if len(atomic_classes) > 1:
+                if rest:
+                    if isinstance(rest[0], int):
+                        next_cls = atomic_classes[rest[0]]
+                        del rest[0]
+                    else:
+                        raise AttributeError(
+                            f"Unknown property {rest[0]} on class collection tuple for {key}"
+                        )
+                else:
+                    public_atomic_classes = tuple(
+                        public_class(typecls, preserve_subtraction=preserve_subtraction)
+                        for typecls in atomic_classes
+                    )
+                    if (
+                        len(frozenset(public_atomic_classes)) == 1
+                        and len(public_atomic_classes) > 1
+                    ):
+                        return public_atomic_classes[0]
+                    return public_atomic_classes
+            else:
+                next_cls, = atomic_classes
+        return public_class(next_cls, *rest, preserve_subtraction=preserve_subtraction)
     cls = getattr(cls, "_parent", cls)
-    if preserve_subtraction and cls._skipped_fields:
+    if preserve_subtraction and any((cls._skipped_fields, cls._modified_fields)):
         return cls
-    if cls._skipped_fields:
+    if any((cls._skipped_fields, cls._modified_fields)):
         bases = tuple(x for x in cls.__bases__ if ismetasubclass(x, Atomic))
-        while len(bases) == 1 and bases[0]._skipped_fields:
+        while len(bases) == 1 and any((bases[0]._skipped_fields, bases[0]._modified_fields)):
             bases = tuple(x for x in cls.__bases__ if ismetasubclass(x, Atomic))
         if len(bases) == 1:
             return bases[0]
@@ -988,6 +1007,15 @@ def find_users_of(mutant_class_parent_names, in_cls):
             yield (key, value), matches
 
 
+def is_defined_coerce(cls, key):
+    for cls_item in inspect.getmro(cls):
+        coerce_mappings = getattr(cls_item, "__coerce__", None)
+        if coerce_mappings is not None:
+            if key in coerce_mappings:
+                return coerce_mappings[key]
+    return None
+
+
 class Atomic(type):
     __slots__ = ()
     REGISTRY = ReadOnly(set())
@@ -1054,9 +1082,14 @@ class Atomic(type):
         if not effective_skipped_fields:
             return self
         try:
-            return root_class.SKIPPED_FIELDS[(self.__qualname__, effective_skipped_fields)]
+            value = root_class.SKIPPED_FIELDS[(cls.__qualname__, effective_skipped_fields)]
         except KeyError:
+            # print(f"Cache miss for {self.__qualname__}")
             pass
+        else:
+            # print(f"Cache hit for {self.__qualname__}")
+            return value
+        skip_fields = effective_skipped_fields
 
         redefinitions = None
         redefine_coerce = None
@@ -1075,9 +1108,7 @@ class Atomic(type):
                 key_specific_strip_keys = frozenset((key_specific_strip_keys,))
 
             current_definition = self._slots[key]
-            current_coerce = None
-            if self.__coerce__ and key in self.__coerce__:
-                current_coerce = self.__coerce__[key]
+            current_coerce = is_defined_coerce(self, key)
             redefined_definition, redefined_coerce_definition, new_mutants = apply_skip_keys(
                 key_specific_strip_keys, current_definition, current_coerce
             )
@@ -1112,6 +1143,7 @@ class Atomic(type):
 
         if redefinitions:
             attrs["__slots__"] = redefinitions
+            attrs["_modified_fields"] = tuple(redefinitions)
         if redefine_coerce:
             attrs["__coerce__"] = redefine_coerce
 
@@ -1125,7 +1157,7 @@ class Atomic(type):
         if not changes:
             return self
         value = type(f"{cls.__name__}{changes}", (cls,), attrs, skip_fields=skip_entire_keys)
-        root_class.SKIPPED_FIELDS[(self.__qualname__, value._skipped_fields)] = value
+        root_class.SKIPPED_FIELDS[(cls.__qualname__, value._skipped_fields)] = value
         return value
 
     def __new__(
@@ -1588,6 +1620,8 @@ class Atomic(type):
             nested_atomic_collections
         )
         support_cls_attrs["_skipped_fields"] = skip_fields
+        if "_modified_fields" not in support_cls_attrs:
+            support_cls_attrs["_modified_fields"] = ()
         conf = AttrsDict(**mixins)
         conf["fast"] = fast
         extra_slots = tuple(_dedupe(pending_extra_slots))
